package com.ruoyi.dashboard.domain.revenueStat;

import java.time.LocalDate;
import java.util.List;

import org.springframework.format.annotation.DateTimeFormat;

import com.ruoyi.bst.bonus.domain.BonusQuery;
import com.ruoyi.bst.bonus.domain.enums.BonusStatus;
import com.ruoyi.bst.bonusRefund.domain.BonusRefundQuery;
import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.order.domain.enums.OrderStatus;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

@Data
public class RevenueStatQuery {
    @ApiModelProperty("日期范围")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private List<LocalDate> dateRange;

    @ApiModelProperty("查询数据")
    private List<String> keys;

    @ApiModelProperty("用户ID")
    private Long userId;

    @ApiModelProperty("运营区ID")
    private Long areaId;

    @ApiModelProperty("数据隔离")
    private Boolean scope;
    

    private OrderQuery baseOrderQuery() {
        OrderQuery query = new OrderQuery();
        query.setStatusList(OrderStatus.valid());
        query.setUserId(userId);
        query.setAreaId(areaId);
        query.setScope(scope);
        return query;
    }

    private BonusQuery baseBonusQuery() {
        BonusQuery query = new BonusQuery();
        query.setStatusList(BonusStatus.valid());
        query.setArrivalId(userId);
        query.setAreaId(areaId);
        query.setScope(scope);
        return query;
    }

    private BonusRefundQuery baseBonusRefundQuery() {   
        BonusRefundQuery query = new BonusRefundQuery();
        query.setBonusStatusList(BonusStatus.valid());
        query.setBonusArrivalId(userId);
        query.setBonusAreaId(areaId);
        query.setScope(scope);
        return query;
    }

    public OrderQuery toOrderQuery() {
        OrderQuery query = baseOrderQuery();
        query.setCreateDateRange(dateRange);
        return query;
    }

    public OrderQuery toOrderQueryForEnd() {
        OrderQuery query = baseOrderQuery();
        query.setEndDateRange(dateRange);
        return query;
    }

    public BonusQuery toBonusQuery() {
        BonusQuery query = baseBonusQuery();
        query.setCreateDateRange(dateRange);
        return query;
    }

    public BonusRefundQuery toBonusRefundQuery() {
        BonusRefundQuery query = baseBonusRefundQuery();
        query.setCreateDateRange(dateRange);
        return query;
    }
}
